@@ -22,6 +22,8 @@ function(files,
          splitting.rule = NULL,
          sample.size = 10000,
          sampling = "no.sampling",
+         sample.overlap = 0,
+         number.of.samples = 1,
          sampling.with.replacement = FALSE,
          features = "w",
          ngram.size = 1,
